import sys
import os
from setuptools.command.install import install

project_name = "kdLaunchPad"
class install_cmd(install):
    def run(self):
        install.run(self)
        try :
            if sys.platform =="win32" :
                    script_file =  os.path.join(self._get_desktop_folder(),project_name + '.bat')
                    with open(script_file, "w") as f:
                        f.write("@echo off\r\nstart " + project_name + ".exe")
            elif sys.platform == "linux":
                    import stat
                    script_file =  os.path.join(self._get_desktop_folder(),project_name + '.sh')
                    with open(script_file, "w") as f:
                        f.write("#!/bin/sh\n" + project_name)
                        st = os.stat(script_file)
                        os.chmod(script_file, st.st_mode | stat.S_IEXEC)
        except Exception as e:
            print("can not create start script." + str(e))
    def _get_desktop_folder(self):
        import subprocess
        try:
            return subprocess.check_output(['xdg-user-dir',
                                            'DESKTOP']).decode('utf-8').strip()
        except Exception:
            return os.path.join(os.path.expanduser('~'), 'Desktop')   



#!/usr/bin/env python3
#-*- coding:utf-8 -*-
'''
本地调试时，python3 main.py即可启动本程序
Created on 2019年3月3日
@author: bkd
'''

from tkinter import messagebox

if __name__ == '__main__':
#         防止初始化异常
    try:
        from kdLaunchPad.kdLaunchPad import main
        main()
    except Exception as e:
        print("系统异常", str(e))
        messagebox.showerror("系统异常", str(e))    


# coding: utf-8
import os

cur_dir = os.path.dirname(os.path.realpath(__file__))
def get_file_realpath(file):
    return os.path.join(cur_dir,file)
def check_and_create(absolute_file_path):
    slash_last_index = absolute_file_path.rindex("/")
    path = absolute_file_path[:slash_last_index]
    # 检查目录
    if os.path.exists(path) is not True:
        os.makedirs(path)
    elif os.path.isdir(path) is not True:
        print(path, "is no a dir,delete and create a dir")
        os.remove(path)
        os.makedirs(path)
    # 检查文件
    if os.path.exists(absolute_file_path) is not True:
        with open(absolute_file_path, "w+") :
            pass
    elif os.path.isfile(absolute_file_path) is not True:
        os.removedirs(absolute_file_path)
        with open(absolute_file_path, "w+"):
            pass

def check_and_create_dir(absolute_dir_path):
    if os.path.exists(absolute_dir_path) is not True:
        os.makedirs(absolute_dir_path)
    elif os.path.isdir(absolute_dir_path) is not True:
        print(absolute_dir_path, "is no a dir,delete and create a dir")
        os.remove(absolute_dir_path)
        os.makedirs(absolute_dir_path)



# -*- coding:utf-8 -*-
'''
Created on 2019年3月3日

@author: bkd
'''

import sys
import os

from PyQt5.uic import loadUi
from PyQt5.QtCore import pyqtSlot,Qt,QPoint,pyqtSignal
from PyQt5.QtWidgets import QWidget,QListView,QSizePolicy,QAction,QMenu,QInputDialog,QLineEdit
from PyQt5.QtGui import QStandardItem,QStandardItemModel,QCursor
from .sessionItem import sessionItem
from .fileutil import get_file_realpath


class launchSession(QWidget):
    add_item_signal = pyqtSignal(dict)
    del_item_signal = pyqtSignal(dict)
    alter_session_signal = pyqtSignal(str,str)
    del_session_signal = pyqtSignal(str)
    
    def __init__(self):
        super().__init__()
        loadUi(get_file_realpath("launchSession.ui"), self)
        self.maxSize = QSizePolicy(QSizePolicy.Maximum,QSizePolicy.Maximum)
        
        self.popMenu = QMenu()
        self.bold = [QAction("新增"),QAction("删除")]
        self.lv_session.setContextMenuPolicy(Qt.CustomContextMenu)
        self.lv_session.customContextMenuRequested[QPoint].connect(self.myListWidgetContext)

        self.lb_session_pop_menu = QMenu()
        self.lb_session_pop_menu_item = [QAction("修改会话"),QAction("删除会话")]
        self.lb_session_name.setContextMenuPolicy(Qt.CustomContextMenu)
        self.lb_session_name.customContextMenuRequested[QPoint].connect(self.handle_lb_session_name_pop_menu)
        
        self.model = QStandardItemModel()
        self.lv_session.setSizePolicy(self.maxSize)
        self.lv_session.setModel(self.model)
        self.lv_session.setViewMode(QListView.ListMode)
        self.lv_session.doubleClicked.connect(self.on_item_doubleClicked)
        
        self.last_path = os.path.expanduser('~')

    def init_session(self,conf):
        session_name = conf["session_name"]
        self.session_name = session_name
        session_list = conf["session_list"]
        self.lb_session_name.setText(session_name)
        self.lv_session.setObjectName(session_name)
        print("add new session," + session_name)

        if session_list:
            for session_list_item in session_list:
                standard_item = QStandardItem(session_list_item["name"])
                standard_item.setData(session_list_item["cmd"])
                standard_item.setEditable(False)
                self.model.appendRow(standard_item)
#                 self.lv_session.addItem(session_list_item["name"])
    @pyqtSlot()
    def on_item_doubleClicked(self):
        cur_index = self.lv_session.currentIndex()
        cmd = self.model.item(cur_index.row(), 0).data()
        print(cmd)
        self.run_cmd(cmd)
    @pyqtSlot()
    def on_pb_launch_clicked(self):
        print("get",self.model.rowCount())
        for i in range(self.model.rowCount()):
            cmd = self.model.item(i).data()
            print(self.model.item(i).data())
            self.run_cmd(cmd)
        sys.exit(0)
        
    def run_cmd(self,cmd):
        if os.name == "nt":
            os.startfile(cmd)
        elif os.name == "posix":
            os.system(cmd + " &")
        print(os.name)
    def myListWidgetContext(self):
        action = self.popMenu.exec_(self.bold,QCursor.pos())
        if action:
            action_text = action.text()
            print(action_text)
            if action_text == "新增" :
                self.s = sessionItem(self.last_path)
                if self.s.exec_():
                    print(self.s.le_name.text())
                    standard_item = QStandardItem(self.s.le_name.text())
                    standard_item.setData(self.s.le_cmd.text())
                    standard_item.setEditable(False)
                    self.model.appendRow(standard_item)
#                     self.model.insertRow(self.model.rowCount(),standard_item)
#                     standard_item.setEnabled(True)
#                     self.lv_session.setVisible(True)
                    
                    session_item = {"name":self.s.le_name.text(),"cmd":self.s.le_cmd.text(),"session_name":self.session_name}
                    self.last_path = self.s.le_cmd.text()
                    self.add_item_signal.emit(session_item)
            elif action_text == "删除" :
                cur_index = self.lv_session.currentIndex()
                name = self.model.item(cur_index.row(), 0).text() 
                print(name)
                session_item = {"name":name,"session_name":self.session_name}
                self.del_item_signal.emit(session_item)
                self.model.removeRow(cur_index.row())
#                 s.show()
            
    def handle_lb_session_name_pop_menu(self):
        action = self.lb_session_pop_menu.exec_(self.lb_session_pop_menu_item,QCursor.pos())
        if action:
            action_text = action.text()
            if action_text == "修改会话" :
                new_session_name, ok = QInputDialog.getText(self, "会话标题", "请输入会话标题:", QLineEdit.Normal)
                if ok:
                    self.lb_session_name.setText(new_session_name)
                    self.alter_session_signal.emit(self.session_name,new_session_name)
            elif action_text == "删除会话":
                self.del_session_signal.emit(self.session_name)
                self.close()



import os

config_file = os.path.join(os.path.expanduser('~') , ".config/main/config.json")
cmd =None
name = None

def to_dict():
    return{
        "cmd":cmd,
        "name":name
        }
def from_dict(conf):
    cmd = conf["cmd"]
    name = conf["name"]
    


#!/usr/bin/env python3
#-*- coding:utf-8 -*-
'''
Created on 2019年3月3日
@author: bkd
'''
import os
import sys
import json
import logging

from PyQt5.uic import loadUi
from PyQt5.Qt import QMainWindow
from PyQt5.QtCore import Qt, QPoint
from PyQt5.QtGui import QCursor, QIcon
from PyQt5.QtWidgets import  QApplication, QFileDialog,  QGraphicsOpacityEffect, QAction, QMenu, QInputDialog, QLineEdit,QMessageBox

from . import kdconfigutil
from . import kdconfig
from .launchSession import launchSession
from .fileutil import  check_and_create,get_file_realpath
from .exception_handler import global_exception_hander

log = logging.getLogger(__name__)
class kdLaunchPad(QMainWindow):

    def __init__(self):
        super().__init__()
        print(os.path.realpath(__file__))
        loadUi(get_file_realpath("kdLaunchPad.ui"), self)
        self.setWindowIcon(QIcon(get_file_realpath('image/kdLaunchPad.ico')))
        
        self.exception_handler = global_exception_hander()
        self.exception_handler.patch_excepthook()
        
        self.confs = kdconfigutil.init_conf()
        print(self.confs)
        self.row = 0
        self.col = 0
        if self.confs:
            self.init_menu(self.confs)
        else :
            self.confs = []
        opacity_effect = QGraphicsOpacityEffect(self)
        opacity_effect.setOpacity(0.95)
        self.setGraphicsEffect(opacity_effect)
        
        self.pop_menu = QMenu()
        self.pop_menu_item = [QAction("新增会话"),QAction("设置背景"),QAction("导出配置"),QAction("导入配置"),QAction("退出")]
        self.setContextMenuPolicy(Qt.CustomContextMenu)
        self.customContextMenuRequested[QPoint].connect(self.handle_pop_menu)
        
        self.set_background_image(get_file_realpath("image/background.jpg").replace("\\","/"))
        
    def init_menu(self,confs):
        for conf in confs:
            ls = launchSession()
            ls.init_session(conf)
            ls.add_item_signal.connect(self.add_session_item)
            ls.del_item_signal.connect(self.del_session_item)
            ls.alter_session_signal.connect(self.alter_session_name)
            ls.del_session_signal.connect(self.del_session)
            self.gridLayout.addWidget(ls,self.row,self.col)
            self.col += 1
            if self.col >= 3:
                self.col = 0
                self.row += 1
    def add_session_item(self,session_item):
        session_name = session_item["session_name"]
        for conf in self.confs:
            if conf["session_name"] == session_name :
                print(session_item)
                new_item = {"name":session_item["name"],"cmd":session_item["cmd"]}
                conf["session_list"].append(new_item)
                kdconfigutil.update_conf(self.confs)
                break
    def del_session_item(self,session_item):
        print("删除",session_item)
        session_name = session_item["session_name"]
        for conf in self.confs:
            if conf["session_name"] == session_name :
                for item in conf["session_list"]:
                    if item["name"] == session_item["name"] :
                        print(item["name"])
                        conf["session_list"].remove(item)
                        break
                kdconfigutil.update_conf(self.confs)
                break
        
    def handle_pop_menu(self):
        action = self.pop_menu.exec_(self.pop_menu_item,QCursor.pos())
        if action:
            action_text = action.text()
            if action_text == "新增会话" :
                value, ok = QInputDialog.getText(self, "会话标题", "请输入会话标题:", QLineEdit.Normal)
                if ok:
                    ls = launchSession()
                    ls.session_name = value
                    ls.lb_session_name.setText(value)
                    ls.lv_session.setObjectName(value)
                    ls.add_item_signal.connect(self.add_session_item)
                    ls.del_item_signal.connect(self.del_session_item)
                    ls.alter_session_signal.connect(self.alter_session_name)
                    ls.del_session_signal.connect(self.del_session)
                    self.gridLayout.addWidget(ls,self.row,self.col)
                    self.col += 1
                    if self.col >= 3:
                        self.col = 0
                        self.row += 1
                    new_session = {"session_name":value,"session_list":[]}
                    self.confs.append(new_session)
                    kdconfigutil.update_conf(self.confs)
                    self.repaint()
            elif action_text == "设置背景":
                filename, _ = QFileDialog.getOpenFileName(self,
                            "选择背景文件",
                            os.path.expanduser('~') , 
                            "(*.jpg);;(*.png)")   #设置文件扩展名过滤,注意用双分号间隔
                if filename:
                    print(filename)
                    self.set_background_image(filename)
            elif action_text == "退出" :
                self.close()
            elif action_text == "导出配置" :
                filename, _ = QFileDialog.getSaveFileName(self,
                            "选择配置文件保存位置",
                            os.path.expanduser('~') , 
                            "配置文件(*.json);;")   #设置文件扩展名过滤,注意用双分号间隔
                if filename:
                        check_and_create(filename)
                        with open(filename, "w") as f:
                            f.write(json.dumps(self.confs,ensure_ascii=False))
                            f.flush()
                            QMessageBox.information(self, "导出配置","导出配置成功", QMessageBox.Yes)
            elif action_text == "导入配置" :
                filename, _ = QFileDialog.getOpenFileName(self,
                            "选择配置文件",
                            os.path.expanduser('~') , 
                            "*.json(*.json)")   #设置文件扩展名过滤,注意用双分号间隔
                if filename:
                    with open(filename,"r") as f :
                        config_content = f.read().strip()
                        if config_content != "" :
                            with open(kdconfig.config_file, "w") as fw:
                                fw.write(config_content)
                                fw.flush()
                                QMessageBox.information(self, "导入配置", "导入配置成功\n重新后将使用新的配置", QMessageBox.Yes)
                
    def alter_session_name(self,old_session_name,new_session_name):
        for conf in self.confs:
            if conf["session_name"] == old_session_name:
                conf["session_name"] = new_session_name
                kdconfigutil.update_conf(self.confs)

    def del_session(self, old_session_name):
        print("删除" + old_session_name)
        for conf in self.confs:
            if conf["session_name"] == old_session_name:
                self.confs.remove(conf)
                print("删除会话成功" + old_session_name)
                kdconfigutil.update_conf(self.confs)
                self.col -= 1
                if self.col < 0 :
                    self.col = 2
                    self.row -= 1
                self.repaint()
               
    def set_background_image(self,filename):
        self.setStyleSheet("#MainWindow{border-image:url("+filename +");}")
        print(filename)
        if os.path.basename(filename) != "background.jpg":
            with open(filename,"rb") as new_background:
                with open(get_file_realpath("image/background.jpg"),"wb") as old_background:
                    old_background.write(new_background.read())

    def keyPressEvent(self, event):
        curKey = event.key()
        print("按下：" + str(event.key()))
        if curKey == Qt.Key_Escape :
            self.showNormal()
        elif curKey == Qt.Key_F4:
            self.close()
        elif curKey == Qt.Key_F11:
            self.showNormal()
def main():
    app = QApplication(sys.argv)
    win = kdLaunchPad()
    win.showFullScreen()
#     win.setWindowOpacity(0.9)
#     win.show()
    sys.exit(app.exec_())
if __name__ == '__main__':
    main()


'''
Created on 2019年3月22日

@author: bkd
'''

import os

from PyQt5.uic import loadUi
from PyQt5.QtCore import pyqtSlot
from PyQt5.QtWidgets import QDialog,QFileDialog

class sessionItem(QDialog):
    def __init__(self,last_path = None):
        super().__init__()
        loadUi("sessionItem.ui", self)
        self.last_path = last_path
    
    @pyqtSlot()
    def on_pb_open_file_clicked(self):
        filename, _ = QFileDialog.getOpenFileName(self,
                                    "閫夋嫨鏂囦欢",
                                     self.last_path,
                                    "All Files (*)")   #璁剧疆鏂囦欢鎵╁睍鍚嶈繃婊�,娉ㄦ剰鐢ㄥ弻鍒嗗彿闂撮殧
        if filename:
            print(filename)
            self.le_cmd.setText(filename)
            self.le_name.setText(os.path.basename(filename))



# coding: utf-8

import json
from .fileutil import check_and_create
from . import kdconfig


def init_conf():
    check_and_create(kdconfig.config_file)
    with open(kdconfig.config_file, "r") as f:
        content = f.read()
        if content.strip() != "":
            conf = json.loads(content)
            return conf


def update_conf(confs):
    check_and_create(kdconfig.config_file)
    with open(kdconfig.config_file, "w") as f:
        print(confs)
        f.write(json.dumps(confs,ensure_ascii=False))
        f.flush()



#!/usr/bin/env python
#-*- coding:utf-8 -*-

from setuptools import setup, find_packages
from install_script import install_cmd 
        
with open("README.md", "r",encoding="utf-8") as fh:
    long_description = fh.read()

        
setup(
#     固定部分
    name="kdLaunchPad",
    version="1.0.8",
    author="bkdwei",
    author_email="bkdwei@163.com",
    maintainer="韦坤东",
    maintainer_email="bkdwei@163.com",
    long_description=long_description,
#     long_description_content_type="text/markdown",
    url="https://github.com/bkdwei/kdLaunchPad",
    license="GPLv3+",
    platforms=["any"],
    
#     需要安装的依赖
    install_requires=["PyQt5"],
    packages=find_packages(),
    zip_safe=False,
    include_package_data=True,
    python_requires='>=3.4',

#     可变部分
    description="auto run some programs after system start",
    keywords=("kdLaunchPad","autoStarter"),
#    https://pypi.org/classifiers/
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: X11 Applications :: Qt",
        "Intended Audience :: End Users/Desktop",
        "Natural Language :: Chinese (Simplified)",
        "Topic :: System :: Boot :: Init",
        "Programming Language :: Python :: 3",
        " License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
        
    ],
    
     # 添加这个选项，在windows下Python目录的scripts下生成exe文件
     # 注意：模块与函数之间是冒号:
     # 终端运行用console_scripts
    entry_points={
        'gui_scripts': [
            'kdLaunchPad=kdLaunchPad.kdLaunchPad:main'
        ],    
    },
    cmdclass={
        'install': install_cmd,
    }
)



'''
Created on 2019年4月8日

@author: bkd
'''
from traceback import format_exception
import sys
from PyQt5.QtWidgets import QMessageBox

class global_exception_hander:
    def new_except_hook(self,etype, evalue, tb):
        print(''.join(format_exception(etype, evalue, tb)))
        QMessageBox.information(None, 
                                      str('error'),
                                      ''.join(format_exception(etype, evalue, tb)))
        sys.exit()
    
#     注册全局异常处理类
    def patch_excepthook(self):
        sys.excepthook = self.new_except_hook